@@ -510,7 +510,7 @@ def makemask(mask,A,savefile=None):
     fig.mydata['mode']=None
     fig.mydata['mask']=mask.astype('bool')
     fig.mydata['redrawneeded']=True
-    conn_id=fig.canvas.mpl_connect('button_press_event',clickevent)
+    fig.canvas.mpl_connect('button_press_event',clickevent)
     fig.toexit=False
     fig.show()
     firstdraw=1;
@@ -607,16 +607,17 @@ def basicfittinggui(data,title='',blocking=False):
     ax=pylab.axes((leftborder,topborder-(len(buttons)+len(plots))*(0.8)/(len(buttons)+len(plots)),leftbox_end,0.7/(len(buttons)+len(plots))*len(plots) ))
     pylab.title('Plot types')
     rb=matplotlib.widgets.RadioButtons(ax,plots,active=7)
-    if blocking:
+    pylab.gcf().blocking=blocking
+    if pylab.gcf().blocking:
         ax=pylab.axes((leftborder,0.03,leftbox_end,bottomborder-0.03))
         b=matplotlib.widgets.Button(ax,"Done")
         fig=pylab.gcf()
         fig.fittingdone=False
-        def onclick(A=None,B=None,fig=fig):
+        def onclick1(A=None,B=None,fig=fig):
             fig.fittingdone=True
-            blocking=False
+            pylab.gcf().blocking=False
      #       print "blocking should now end"
-        b.on_clicked(onclick)
+        b.on_clicked(onclick1)
     pylab.axes((0.4,bottomborder,0.5,0.8))
     def onselectplottype(plottype,q=data['q'],I=data['Intensity'],title=title):
         pylab.cla()
@@ -726,6 +727,7 @@ def testorigin(data,orig,mask=None,dmin=None,dmax=None):
         mask: the mask matrix. Nonzero means nonmasked
     """
     print "Creating origin testing images, please wait..."
+    pylab.clf()
     if mask is None:
         mask=np.ones(data.shape)
     print "    plotting matrix with cross-hair..."
@@ -777,15 +779,22 @@ def assesstransmission(fsns,titleofsample,mode='Gabriel',dirs=[]):
         mode: 'Gabriel' if the measurements were made with the gas-detector, 
             and 'Pilatus300k' if that detector was used.            
     """
+    hborder=0.08
+    vborder=0.08
+    hspacing=0.02
+    vspacing=0.08
+    axiswidth=0.6
+    axisheight=(1-vborder*2-vspacing*3)/4.
+    
+    
     if type(fsns)!=types.ListType:
         fsns=[fsns]
-    if mode=='Gabriel':
+    if mode.upper().startswith('GABRIEL'):
         header1=B1io.readheader('ORG',fsns,'.DAT',dirs=dirs)
-    elif mode=='Pilatus300k':
+    elif mode.upper().startswith('PILATUS'):
         header1=B1io.readheader('org_',fsns,'.header',dirs=dirs)
     else:
-        print "invalid mode argument. Possible values: 'Gabriel', 'Pilatus300k'"
-        return
+        raise ValueError("invalid mode argument. Possible values: 'Gabriel' or 'Pilatus'")
     params1=B1io.readlogfile(fsns,dirs=dirs)
     header=[]
     for h in header1:
@@ -797,66 +806,60 @@ def assesstransmission(fsns,titleofsample,mode='Gabriel',dirs=[]):
             params.append(h.copy())
     energies=utils.unique([h['Energy'] for h in header],(lambda a,b:abs(a-b)<2))
 
-    doris=[h['Current1'] for h in header]
-    orix=[h['BeamPosX'] for h in params]
-    oriy=[h['BeamPosY'] for h in params]
-    legend1=[]
-    legend2=[]
-    legend3=[]
-    legend4=[]
+    axisTransm=pylab.gcf().add_axes([hborder,1-vborder-axisheight,axiswidth,axisheight])
+    axisBcX=pylab.gcf().add_axes([hborder,1-vborder-2*axisheight-vspacing,axiswidth,axisheight])
+    axisBcY=pylab.gcf().add_axes([hborder,1-vborder-3*axisheight-2*vspacing,axiswidth,axisheight])
+    axisDORIS=pylab.gcf().add_axes([hborder,1-vborder-4*axisheight-3*vspacing,axiswidth,axisheight])
+
     print "Assesstransmission"
     for l in range(len(energies)):
         print "  Energy: ",energies[l]
-        pylab.subplot(4,1,1)
-        bbox=pylab.gca().get_position()
-        pylab.gca().set_position([bbox.x0,bbox.y0,(bbox.x1-bbox.x0)*0.9,bbox.y1-bbox.y0])
-        fsn=[h['FSN'] for h in header if abs(h['Energy']-energies[l])<2]
+        pylab.axes(axisTransm)
+        fsn=[h['FSN'] for h in params if abs(h['Energy']-energies[l])<2]
         transm1=[h['Transm'] for h in params if abs(h['Energy']-energies[l])<2]
+        legend1='Energy (not calibrated) = %.1f eV\n Mean T = %.4f, std %.4f' % (energies[l],np.mean(transm1),np.std(transm1))
         print "    Transmission: mean=",np.mean(transm1),"std=",np.std(transm1)
-        pylab.plot(fsn,transm1,'-o',linewidth=1)
+        pylab.plot(fsn,transm1,'-o',label=legend1,linewidth=1)
         pylab.ylabel('Transmission')
         pylab.xlabel('FSN')
         pylab.grid('on')
-        legend1=legend1+['Energy (not calibrated) = %.1f eV\n Mean T = %.4f, std %.4f' % (energies[l],np.mean(transm1),np.std(transm1))]
-        pylab.subplot(4,1,2)
-        bbox=pylab.gca().get_position()
-        pylab.gca().set_position([bbox.x0,bbox.y0,(bbox.x1-bbox.x0)*0.9,bbox.y1-bbox.y0])
+
+        pylab.axes(axisBcX)
         orix1=[h['BeamPosX'] for h in params if abs(h['Energy']-energies[l])<2]
+        legend2='Energy (not calibrated) = %.1f eV\n Mean x = %.4f, std %.4f' % (energies[l],np.mean(orix1),np.std(orix1))
         print "    BeamcenterX: mean=",np.mean(orix1),"std=",np.std(orix1)
-        pylab.plot(fsn,orix1,'-o',linewidth=1)
+        pylab.plot(fsn,orix1,'-o',label=legend2,linewidth=1)
         pylab.ylabel('Position of beam center in X')
         pylab.xlabel('FSN')
         pylab.grid('on')
-        legend2=legend2+['Energy (not calibrated) = %.1f eV\n Mean x = %.4f, std %.4f' % (energies[l],np.mean(orix1),np.std(orix1))]
-        pylab.subplot(4,1,3)
-        bbox=pylab.gca().get_position()
-        pylab.gca().set_position([bbox.x0,bbox.y0,(bbox.x1-bbox.x0)*0.9,bbox.y1-bbox.y0])
+        
+        pylab.axes(axisBcY)
         oriy1=[h['BeamPosY'] for h in params if abs(h['Energy']-energies[l])<2]
+        legend3='Energy (not calibrated) = %.1f eV\n Mean y = %.4f, std %.4f' % (energies[l],np.mean(oriy1),np.std(oriy1))
         print "    BeamcenterY: mean=",np.mean(oriy1),"std=",np.std(oriy1)
-        pylab.plot(fsn,oriy1,'-o',linewidth=1)
+        pylab.plot(fsn,oriy1,'-o',label=legend3,linewidth=1)
         pylab.ylabel('Position of beam center in Y')
         pylab.xlabel('FSN')
         pylab.grid('on')
-        legend3=legend3+['Energy (not calibrated) = %.1f eV\n Mean y = %.4f, std %.4f' % (energies[l],np.mean(oriy1),np.std(oriy1))]
-        pylab.subplot(4,1,4)
-        bbox=pylab.gca().get_position()
-        pylab.gca().set_position([bbox.x0,bbox.y0,(bbox.x1-bbox.x0)*0.9,bbox.y1-bbox.y0])
+        
+        pylab.axes(axisDORIS)
         doris1=[h['Current1'] for h in header if abs(h['Energy']-energies[l])<2]
+        legend4='Energy (not calibrated) = %.1f eV\n Mean I = %.4f' % (energies[l],np.mean(doris1))
         print "    Doris current: mean=",np.mean(doris1),"std=",np.std(doris1)
-        pylab.plot(fsn,doris1,'o',linewidth=1)
+        fsnh=[h['FSN'] for h in header if abs(h['Energy']-energies[l])<2]
+        pylab.plot(fsnh,doris1,'o',label=legend4,linewidth=1)
         pylab.ylabel('Doris current (mA)')
         pylab.xlabel('FSN')
         pylab.grid('on')
-        legend4=legend4+['Energy (not calibrated) = %.1f eV\n Mean I = %.4f' % (energies[l],np.mean(doris1))]
         
-    pylab.subplot(4,1,1)
-    pylab.legend(legend1,loc=(1.03,0),prop={'size':'small'})
-    pylab.subplot(4,1,2)
-    pylab.legend(legend2,loc=(1.03,0),prop={'size':'small'})
-    pylab.subplot(4,1,3)
-    pylab.legend(legend3,loc=(1.03,0),prop={'size':'small'})
-    pylab.subplot(4,1,4)
-    pylab.legend(legend4,loc=(1.03,0),prop={'size':'small'})
+    pylab.axes(axisTransm)
+    pylab.legend(loc='center left',bbox_to_anchor=(hspacing+hborder+axiswidth,1-vborder-0*vspacing-0.5*axisheight), bbox_transform=pylab.gcf().transFigure,prop={'size':'small'})
+    pylab.axes(axisBcX)
+    pylab.legend(loc='center left',bbox_to_anchor=(hspacing+hborder+axiswidth,1-vborder-1*vspacing-1.5*axisheight), bbox_transform=pylab.gcf().transFigure,prop={'size':'small'})
+    pylab.axes(axisBcY)
+    pylab.legend(loc='center left',bbox_to_anchor=(hspacing+hborder+axiswidth,1-vborder-2*vspacing-2.5*axisheight), bbox_transform=pylab.gcf().transFigure,prop={'size':'small'})
+    pylab.axes(axisDORIS)
+    pylab.legend(loc='center left',bbox_to_anchor=(hspacing+hborder+axiswidth,1-vborder-3*vspacing-3.5*axisheight), bbox_transform=pylab.gcf().transFigure,prop={'size':'small'})
     
 def findpeak(xdata,ydata,prompt=None,mode='Lorentz',scaling='lin',blind=False,return_error=False):
     """GUI tool for locating peaks by zooming on them
@@ -914,7 +917,6 @@ def findpeak(xdata,ydata,prompt=None,mode='Lorentz',scaling='lin',blind=False,re
         res=scipy.optimize.leastsq(gausscostfun,p0,args=(x1,y1),maxfev=10000,full_output=True)
         p1=res[0]
         cov=res[1]
-        ier=res[4]
         if not blind:
             if scaling=='log':
                 pylab.semilogy(x1,p1[3]+p1[0]/(np.sqrt(2*np.pi)*p1[1])*np.exp(-(x1-p1[2])**2/(2*p1[1]**2)),'r-')
@@ -929,7 +931,6 @@ def findpeak(xdata,ydata,prompt=None,mode='Lorentz',scaling='lin',blind=False,re
         res=scipy.optimize.leastsq(lorentzcostfun,p0,args=(x1,y1),maxfev=10000,full_output=True)
         p1=res[0]
         cov=res[1]
-        ier=res[4]
         if not blind:
             if scaling=='log':
                 pylab.semilogy(x1,p1[3]+p1[0]*utils.lorentzian(p1[2],p1[1],x1),'r-')
